# vim:set ft=zsh ai et sw=4 ts=4:
#
# ~/.zshrc.d/functions.zsh

## Do an ls after cd
cd() { builtin cd "$@" && ls; }

## Create new directory and enter it
mkd() { mkdir -p "$@" && cd "$_"; }

## pids
pids() { pgrep -a "$@"; }

## variation of our manzsh() function; pick you poison:
manzsh()  { /usr/bin/man zshall |  most +/"$1" ; }

## restart zsh
restart () {
    exec $SHELL $SHELL_ARGS "$@"
}

rsrc() { cd && clear && restart; }

## parse HackerNews feed (https://hnrss.org/newest)
hn() {
python3 <(cat <<EOF

import feedparser
HNFeed = feedparser.parse("https://hnrss.org/newest")

class bcolors:
    HEADER = '\033[95m'
    ENDC = '\033[0m'

for item in HNFeed.entries:
    print(f"{bcolors.HEADER}%s{bcolors.ENDC}" % item.title)
    print(item.links[0].href)
    print("")

EOF
) | bat -p
}

## fetch open source license
license() {
    local base_url
    base_url="https://api.github.com/licenses"

    local headers
    headers="Accept: application/vnd.github.drax-preview+json"

    local res
    if (( $# == 0 )); then
        res=$(curl --silent --header $headers $base_url)

        echo "Available licenses:"
        echo
        echo "$res" | jq ".[].key" | tr -d '"'
    fi

    local license="$argv[1]"
    res=$(curl --silent --header $headers $base_url/$license | jq ."body")
    echo -e $res | tr -d '"'
}
